#' @title An `htmlwidget` interface to the d3po javascript chart library
#' @name d3po
#' @keywords internal
"_PACKAGE"

#' @title D3po (re)exported methods
#' @name d3po-exports
NULL

#' @importFrom magrittr %>%
#' @name %>%
#' @rdname d3po-exports
NULL

#' @importFrom htmlwidgets JS
#' @name JS
#' @rdname d3po-exports
NULL
